==> zio-aws-networkfirewall_2.12-5.17.126.2-sources.jar: zio/aws/networkfirewall/model/ConfigurationSyncState.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters._
sealed trait ConfigurationSyncState {
  def unwrap: software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState
}
object ConfigurationSyncState {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState
  ): zio.aws.networkfirewall.model.ConfigurationSyncState = value match {
    case software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.PENDING =>
      val r = PENDING
      r
    case software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.IN_SYNC =>
      val r = IN_SYNC
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.ConfigurationSyncState {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState =
      software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.UNKNOWN_TO_SDK_VERSION
  }
  case object PENDING
      extends zio.aws.networkfirewall.model.ConfigurationSyncState {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState =
      software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.PENDING
  }
  case object IN_SYNC
      extends zio.aws.networkfirewall.model.ConfigurationSyncState {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState =
      software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.IN_SYNC
  }
}

==> zio-aws-networkfirewall_2.13-5.20.22.1-sources.jar: zio/aws/networkfirewall/model/ConfigurationSyncState.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters._
sealed trait ConfigurationSyncState {
  def unwrap: software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState
}
object ConfigurationSyncState {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState
  ): zio.aws.networkfirewall.model.ConfigurationSyncState = value match {
    case software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.PENDING =>
      val r = PENDING
      r
    case software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.IN_SYNC =>
      val r = IN_SYNC
      r
    case software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.CAPACITY_CONSTRAINED =>
      val r = CAPACITY_CONSTRAINED
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.ConfigurationSyncState {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState =
      software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.UNKNOWN_TO_SDK_VERSION
  }
  case object PENDING
      extends zio.aws.networkfirewall.model.ConfigurationSyncState {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState =
      software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.PENDING
  }
  case object IN_SYNC
      extends zio.aws.networkfirewall.model.ConfigurationSyncState {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState =
      software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.IN_SYNC
  }
  case object CAPACITY_CONSTRAINED
      extends zio.aws.networkfirewall.model.ConfigurationSyncState {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState =
      software.amazon.awssdk.services.networkfirewall.model.ConfigurationSyncState.CAPACITY_CONSTRAINED
  }
}
